/*
 *   ORXONOX - the hottest 3D action shooter ever to exist
 *                    > www.orxonox.net <
 *
 *
 *   License notice:
 *
 *   This program is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU General Public License
 *   as published by the Free Software Foundation; either version 2
 *   of the License, or (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 *   Author:
 *      Fabian 'x3n' Landau
 *   Co-authors:
 *      ...
 *
 */

#ifndef _LeaderController_H__
#define _LeaderController_H__

#include "SectionController.h"


namespace orxonox
{
    class _OrxonoxExport LeaderController : public SectionController, public Tickable
    {
        public:
           
            LeaderController(Context* context);
            virtual ~LeaderController();

            virtual void tick(float dt); //<! Carrying out the targets set in action().

        protected:
           
            virtual void action(); //<! action() is called in regular intervals managing the bot's behaviour ~ setting targets.
            //void defaultBehaviour(float maxrand); //<! Helper function for code reusage. Some concrete commands for a bot.


            
                
            enum Mode {KEEPFORMATION, ROCKET, KILLENEMY};
            Mode mode_;

            //WEAPONSYSTEM DATA
            std::map<std::string, int> weaponModes_; //<! Links each "weapon" to it's weaponmode - managed by setupWeapons()
            //std::vector<int> projectiles_; //<! Displays amount of projectiles of each weapon. - managed by setupWeapons()
            float timeout_; //<! Timeout for rocket usage. (If a rocket misses, a bot should stop using it.)
            void setupWeapons(); //<! Defines which weapons are available for a bot. Is recalled whenever a bot was killed.
            bool bSetupWorked; //<! If false, setupWeapons() is called.
            int getFiremode(std::string name);

            void boostControl(); //<! Sets and resets the boost parameter of the spaceship. Bots alternate between boosting and saving boost.

        private:
            static const float ACTION_INTERVAL;

            Timer actionTimer_; //<! Regularly calls action().
               
    };
}

#endif /* _LeaderController_H__ */
